N-Quads is a line-based, plain text format for encoding an RDF dataset. This library provides a W3C Recommendation compliant parser that keeps track of the position of each syntax node in the source file using the locspan library.
Re-exports
pub use lexing::NquadsLexingError;pub use rdf_syntax;
Modules
Structs
Enums
Traits
Functions
Type Aliases
- Grdf
Nquad Document - gRDF N-Quads document.
- Nquad
Document - N-Quads document.
- Nquads
Code Map